==> purchaser-invoice-saas-metadata-0.0.76-sources.jar: com/xforceplus/ultraman/app/purchaserinvoicesaas/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.purchaserinvoicesaas.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2022-09-17
 */

public class PageMeta {
    public interface InvoicePool {
        static String code() {
            return "invoicePool";
        }
        static String name() {
            return "发票池";
        }
    }
    public interface InvoicePush {
        static String code() {
            return "invoicePush";
        }
        static String name() {
            return "发票下发履历";
        }
    }
    public interface InvoiceReceive {
        static String code() {
            return "invoiceReceive";
        }
        static String name() {
            return "发票接收履历";
        }
    }
    public interface InvoiceVerifyTask {
        static String code() {
            return "invoiceVerifyTask";
        }
        static String name() {
            return "验真请求记录";
        }
    }
    public interface InvoiceCheck {
        static String code() {
            return "invoiceCheck";
        }
        static String name() {
            return "发票勾选";
        }
    }
    public interface InvoiceDrawback {
        static String code() {
            return "invoiceDrawback";
        }
        static String name() {
            return "发票退税勾选";
        }
    }
    public interface FunctionConfig {
        static String code() {
            return "functionConfig";
        }
        static String name() {
            return "功能点配置";
        }
    }
    public interface TenantFunctionConfig {
        static String code() {
            return "tenantFunctionConfig";
        }
        static String name() {
            return "租户功能配置";
        }
    }
}

==> purchaser-invoice-saas-metadata-0.0.282-sources.jar: com/xforceplus/ultraman/app/purchaserinvoicesaas/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.purchaserinvoicesaas.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2023-04-11
 */

public class PageMeta {
    public interface InvoicePool {
        static String code() {
            return "invoicePool";
        }
        static String name() {
            return "发票池";
        }
    }
    public interface InvoicePush {
        static String code() {
            return "invoicePush";
        }
        static String name() {
            return "发票下发履历";
        }
    }
    public interface InvoiceReceive {
        static String code() {
            return "invoiceReceive";
        }
        static String name() {
            return "发票接收履历";
        }
    }
    public interface InvoiceVerifyTask {
        static String code() {
            return "invoiceVerifyTask";
        }
        static String name() {
            return "验真请求记录";
        }
    }
    public interface FunctionConfig {
        static String code() {
            return "functionConfig";
        }
        static String name() {
            return "功能点配置";
        }
    }
    public interface TenantFunctionConfig {
        static String code() {
            return "tenantFunctionConfig";
        }
        static String name() {
            return "租户功能配置";
        }
    }
    public interface InvoiceCheck {
        static String code() {
            return "invoiceCheck";
        }
        static String name() {
            return "发票未勾选";
        }
    }
    public interface InvoiceChecked {
        static String code() {
            return "invoiceChecked";
        }
        static String name() {
            return "发票已勾选";
        }
    }
    public interface InvoiceDrawbackCheck {
        static String code() {
            return "invoiceDrawbackCheck";
        }
        static String name() {
            return "发票退税未勾选";
        }
    }
    public interface InvoiceDrawbackChecked {
        static String code() {
            return "invoiceDrawbackChecked";
        }
        static String name() {
            return "发票退税已勾选";
        }
    }
    public interface CustomsPaymentCheck {
        static String code() {
            return "customsPaymentCheck";
        }
        static String name() {
            return "海关缴款书未勾选";
        }
    }
    public interface CustomsPaymentChecked {
        static String code() {
            return "customsPaymentChecked";
        }
        static String name() {
            return "海关缴款书已勾选";
        }
    }
    public interface CustomsPaymentDrawbackCheck {
        static String code() {
            return "CustomsPaymentDrawbackCheck";
        }
        static String name() {
            return "海关缴款书退税未勾选";
        }
    }
    public interface CustomsPaymentDrawbackChecked {
        static String code() {
            return "CustomsPaymentDrawbackChecked";
        }
        static String name() {
            return "海关缴款书退税已勾选";
        }
    }
    public interface InvoiceOfflineCheck {
        static String code() {
            return "invoiceOfflineCheck";
        }
        static String name() {
            return "发票离线勾选";
        }
    }
    public interface NcpInvoicePending {
        static String code() {
            return "ncpInvoicePending";
        }
        static String name() {
            return "待处理农产品发票";
        }
    }
    public interface InvoiceEntry {
        static String code() {
            return "invoiceEntry";
        }
        static String name() {
            return "发票入账";
        }
    }
    public interface Operation {
        static String code() {
            return "operation";
        }
        static String name() {
            return "功能运维";
        }
    }
}
